@@ -8,7 +8,7 @@ from ..cli.query import query
 from ..cli.dag import dag
 from ..cli.dryrun import dryrun
 from ..cli.format import format
-from ..cli.udf import udf, mozfun
+from ..cli.routine import routine, mozfun
 from ..glam.cli import glam
 from .._version import __version__
 from ..stripe import stripe_
@@ -21,7 +21,7 @@ def cli():
         "dag": dag,
         "dryrun": dryrun,
         "format": format,
-        "udf": udf,
+        "routine": routine,
         "mozfun": mozfun,
         "stripe": stripe_,
         "glam": glam,
