@@ -3,7 +3,6 @@
 # file, you can obtain one at http://mozilla.org/MPL/2.0/.
 """Utilities."""
 
-from bigquery_etl.udf import parse_udf
 from contextlib import contextmanager
 from dataclasses import dataclass
 from datetime import date, datetime
@@ -46,8 +45,6 @@ TABLE_EXTENSIONS = {
     "orc": bigquery.SourceFormat.ORC,
 }
 
-raw_udfs = parse_udf.read_udf_dirs()
-
 
 @dataclass
 class Table:
