@@ -72,8 +72,10 @@ IMPRESSION_ID = "impression_id"
 USER_ID = "user_id"
 POCKET_ID = "pocket_id"
 SHIELD_ID = "shield_id"
-ECOSYSTEM_CLIENT_ID = "payload.ecosystem_client_id"
-PIONEER_ID = "payload.pioneer_id"
+ECOSYSTEM_CLIENT_ID = "ecosystem_client_id"
+ECOSYSTEM_CLIENT_ID_HASH = f"{ECOSYSTEM_CLIENT_ID}_hash"
+DESKTOP_ECOSYSTEM_CLIENT_ID = f"payload.{ECOSYSTEM_CLIENT_ID}"
+PIONEER_ID = "pioneer_id"
 ID = "id"
 CFR_ID = f"COALESCE({CLIENT_ID}, {IMPRESSION_ID})"
 FXA_USER_ID = "jsonPayload.fields.user_id"
@@ -93,6 +95,14 @@ CFR_SRC = DeleteSource(
     f" UNNEST([{CLIENT_ID}, {IMPRESSION_SRC.field}]) AS `_",
     field="_",
 )
+ECOSYSTEM_CLIENT_ID_HMAC_SRC = DeleteSource(
+    table="account_ecosystem_restricted.ecosystem_client_id_deletion_v1",
+    field=ECOSYSTEM_CLIENT_ID_HASH,
+)
+ECOSYSTEM_CLIENT_ID_SRC = DeleteSource(
+    table="account_ecosystem_restricted.ecosystem_client_id_deletion_v1",
+    field=ECOSYSTEM_CLIENT_ID,
+)
 FXA_HMAC_SRC = DeleteSource(
     table="firefox_accounts_derived.fxa_delete_events_v1", field="hmac_user_id"
 )
@@ -124,7 +134,15 @@ LEGACY_MOBILE_SOURCES = tuple(
     )
 )
 SOURCES = (
-    [DESKTOP_SRC, IMPRESSION_SRC, CFR_SRC, FXA_HMAC_SRC, FXA_SRC]
+    [
+        DESKTOP_SRC,
+        IMPRESSION_SRC,
+        CFR_SRC,
+        ECOSYSTEM_CLIENT_ID_HMAC_SRC,
+        ECOSYSTEM_CLIENT_ID_SRC,
+        FXA_HMAC_SRC,
+        FXA_SRC,
+    ]
     + list(SYNC_SOURCES)
     + list(LEGACY_MOBILE_SOURCES)
 )
@@ -138,6 +156,7 @@ impression_id_target = partial(DeleteTarget, field=IMPRESSION_ID)
 cfr_id_target = partial(DeleteTarget, field=CFR_ID)
 fxa_user_id_target = partial(DeleteTarget, field=FXA_USER_ID)
 user_id_target = partial(DeleteTarget, field=USER_ID)
+pioneer_target = partial(DeleteTarget, field=PIONEER_ID)
 
 DELETE_TARGETS = {
     client_id_target(
@@ -254,6 +273,21 @@ DELETE_TARGETS = {
     user_id_target(
         table="firefox_accounts_derived.fxa_users_services_last_seen_v1"
     ): FXA_SRC,
+    # account ecosystem telemetry (AET)
+    DeleteTarget(
+        table="telemetry_stable.account_ecosystem_v4", field=DESKTOP_ECOSYSTEM_CLIENT_ID
+    ): ECOSYSTEM_CLIENT_ID_SRC,
+    DeleteTarget(
+        table="firefox_accounts_stable.account_ecosystem_v1", field=ECOSYSTEM_CLIENT_ID
+    ): ECOSYSTEM_CLIENT_ID_SRC,
+    DeleteTarget(
+        table="account_ecosystem_derived.ecosystem_client_id_lookup_v1",
+        field=ECOSYSTEM_CLIENT_ID_HASH,
+    ): ECOSYSTEM_CLIENT_ID_HMAC_SRC,
+    DeleteTarget(
+        table="account_ecosystem_derived.desktop_clients_daily_v1",
+        field=ECOSYSTEM_CLIENT_ID_HASH,
+    ): ECOSYSTEM_CLIENT_ID_HMAC_SRC,
     # legacy mobile
     DeleteTarget(
         table="telemetry_stable.core_v1",
@@ -335,7 +369,7 @@ SEARCH_IGNORE_TABLES |= {
         # other
         DeleteTarget(table="telemetry_stable.pioneer_study_v4", field=PIONEER_ID),
         DeleteTarget(
-            table="telemetry_stable.pre_account_v4", field=ECOSYSTEM_CLIENT_ID
+            table="telemetry_stable.pre_account_v4", field=DESKTOP_ECOSYSTEM_CLIENT_ID
         ),
     ]
 }
@@ -441,3 +475,87 @@ def find_experiment_analysis_targets(pool, client, project=EXPERIMENT_ANALYSIS):
         client_id_target(table=qualified_table_id(table)): DESKTOP_SRC
         for table in tables
     }
+
+
+PIONEER_PROD = "moz-fx-data-pioneer-prod"
+
+
+def find_pioneer_targets(pool, client, project=PIONEER_PROD, study_projects=[]):
+    """Return a dict like DELETE_TARGETS for Pioneer tables."""
+
+    def __get_tables_with_pioneer_id__(dataset_list):
+        return [
+            table
+            for table in pool.map(
+                client.get_table,
+                [
+                    table
+                    for tables in pool.map(
+                        client.list_tables,
+                        dataset_list,
+                        chunksize=1,
+                    )
+                    for table in tables
+                ],
+                chunksize=1,
+            )
+            if any(field.name == PIONEER_ID for field in table.schema)
+            and table.table_type != "VIEW"
+        ]
+
+    datasets = {
+        dataset.reference
+        for dataset in client.list_datasets(project)
+        if dataset.reference.dataset_id.startswith("pioneer_")
+    }
+    # There should be a single stable and derived dataset per study
+    stable_datasets = {dr for dr in datasets if dr.dataset_id.endswith("_stable")}
+    derived_datasets = {dr for dr in datasets if dr.dataset_id.endswith("_derived")}
+
+    stable_tables = [
+        table
+        for tables in pool.map(client.list_tables, stable_datasets, chunksize=1)
+        for table in tables
+    ]
+
+    sources = {
+        table.dataset_id: DeleteSource(qualified_table_id(table), PIONEER_ID, project)
+        # dict comprehension will only keep the last value for a given key, so
+        # sort by table_id to use the latest version
+        for table in sorted(stable_tables, key=lambda t: t.table_id)
+        if table.table_id.startswith("deletion_request_")
+    }
+
+    # we only expect analysis tables to be created under `analysis` datasets
+    analysis_datasets = [project + ".analysis" for project in study_projects]
+
+    return {
+        **{
+            # stable tables
+            pioneer_target(
+                table=qualified_table_id(table), project=PIONEER_PROD
+            ): sources[table.dataset_id]
+            for table in stable_tables
+            if not table.table_id.startswith("deletion_request_")
+            and not table.table_id.startswith("pioneer_enrollment_")
+        },
+        **{
+            # derived tables with pioneer_id
+            pioneer_target(
+                table=qualified_table_id(table), project=PIONEER_PROD
+            ): sources[table.dataset_id]
+            for table in __get_tables_with_pioneer_id__(derived_datasets)
+        },
+        **{
+            # tables with pioneer_id located in study analysis projects
+            pioneer_target(
+                table=qualified_table_id(table), project=table.project
+            ):  # The following finds corresponding delete request table.
+            # By convention, it is located under stable study dataset in
+            # PIONEER_PROD project
+            sources[
+                re.sub("^moz-fx-data-", "", table.project).replace("-", "_") + "_stable"
+            ]
+            for table in __get_tables_with_pioneer_id__(analysis_datasets)
+        },
+    }
