@@ -26,6 +26,7 @@ from .config import (
     DELETE_TARGETS,
     find_glean_targets,
     find_experiment_analysis_targets,
+    find_pioneer_targets,
 )
 
 
@@ -44,6 +45,13 @@ parser.add_argument(
     "telemetry - standard environment"
     "pioneer - restricted pioneer environment",
 )
+parser.add_argument(
+    "--pioneer-study-projects",
+    "--pioneer_study_projects",
+    default=[],
+    help="Pioneer study-specific analysis projects to include in data deletion.",
+    type=lambda s: [i for i in s.split(",")],
+)
 parser.add_argument(
     "--partition-limit",
     "--partition_limit",
@@ -420,7 +428,10 @@ def main():
             experiment_analysis_targets.items(),
         )
     elif args.environment == "pioneer":
-        raise NotImplementedError
+        with ThreadPool(args.parallelism) as pool:
+            targets_with_sources = find_pioneer_targets(
+                pool, client, study_projects=args.pioneer_study_projects
+            ).items()
 
     tasks = [
         task
